import 'package:flutter/material.dart';
import 'package:xinlake_platform/xinlake_platform.dart';

class PickFilesDemo extends StatefulWidget {
  const PickFilesDemo({Key? key}) : super(key: key);

  @override
  State<PickFilesDemo> createState() => _PickFilesState();
}

class _PickFilesState extends State<PickFilesDemo> {
  // parameters
  bool _multiSelection = false;
  String _mimeType = "*/*";
  AndroidAppDir _cacheDir = AndroidAppDir.internalCache;
  bool _cacheOverwrite = false;
  String _openPath = "";
  String _defaultPath = "";
  String _filterName = "All files";
  String _filterPattern = "*.*";

  // result
  List<String>? _pathList;

  bool _enableCache = false;

  void _pickFiles() async {
    var pathList = await XinlakePlatform.pickFiles(
      multiSelection: _multiSelection,
      mimeType: _mimeType,
      cacheDir: _enableCache ? _cacheDir : null,
      cacheOverwrite: _cacheOverwrite,
      openPath: _openPath,
      defaultPath: _defaultPath,
      filterName: _filterName,
      filterPattern: _filterPattern,
    );

    setState(() => _pathList = pathList);
  }

  Widget _buildResults() {
    final style = Theme.of(context).textTheme.caption;
    // empty view
    if (_pathList == null) {
      return Center(
        child: Text(
          "NULL",
          textScaleFactor: 2,
          style: style,
        ),
      );
    } else if (_pathList!.isEmpty) {
      return Center(
        child: Text(
          "EMPTY",
          textScaleFactor: 2,
          style: style,
        ),
      );
    }

    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(
          "${_pathList!.length} ${_pathList!.length > 1 ? "files" : "file"} selected",
          style: style,
        ),
        ..._pathList!.map<Widget>((path) {
          return Padding(
            padding: const EdgeInsets.symmetric(vertical: 5),
            child: Text(
              path,
              maxLines: 3,
              overflow: TextOverflow.ellipsis,
            ),
          );
        }).toList(),
      ],
    );
  }

  Widget _buildParameter() {
    return Column(
      children: [
        // all platform
        Row(
          children: [
            const Expanded(child: Text("Multi selection")),
            Expanded(
              child: Align(
                alignment: Alignment.centerLeft,
                child: Switch(
                  value: _multiSelection,
                  onChanged: (value) => setState(() => _multiSelection = value),
                ),
              ),
            ),
          ],
        ),
        const SizedBox(height: 10),
        // android
        Row(
          children: const [
            Expanded(child: Divider(height: 1)),
            Text(
              "ANDROID",
              style: TextStyle(fontStyle: FontStyle.italic, color: Colors.blueGrey),
            ),
          ],
        ),
        TextFormField(
          decoration: const InputDecoration(labelText: "Mime type"),
          initialValue: _mimeType,
          onChanged: (value) => _mimeType = value,
        ),
        Column(
          mainAxisSize: MainAxisSize.min,
          crossAxisAlignment: CrossAxisAlignment.stretch,
          children: [
            const SizedBox(height: 20),
            Row(
              children: [
                const Expanded(child: Text("Cache dir")),
                Expanded(
                  child: Align(
                    alignment: Alignment.centerLeft,
                    child: Switch(
                      value: _enableCache,
                      onChanged: (value) => setState(() => _enableCache = value),
                    ),
                  ),
                ),
              ],
            ),
            const SizedBox(height: 5),
            DropdownButton<AndroidAppDir>(
              underline: Container(
                height: 1,
                color: Theme.of(context).colorScheme.background,
              ),
              value: _cacheDir,
              isDense: true,
              onChanged: _enableCache
                  ? (newValue) {
                      setState(() => _cacheDir = newValue!);
                    }
                  : null,
              items: AndroidAppDir.values.map<DropdownMenuItem<AndroidAppDir>>((item) {
                return DropdownMenuItem<AndroidAppDir>(
                  value: item,
                  child: Text(item.toString()),
                );
              }).toList(),
            ),
            const SizedBox(height: 20),
          ],
        ),
        Row(
          children: [
            const Expanded(
              child: Text("Cache overwrite"),
            ),
            Expanded(
              child: Align(
                alignment: Alignment.centerLeft,
                child: Switch(
                  value: _cacheOverwrite,
                  onChanged: (value) => setState(() => _cacheOverwrite = value),
                ),
              ),
            ),
          ],
        ),
        const SizedBox(height: 10),
        // windows
        Row(
          children: const [
            Expanded(child: Divider(height: 1)),
            Text(
              "WINDOWS",
              style: TextStyle(fontStyle: FontStyle.italic, color: Colors.blueGrey),
            ),
          ],
        ),
        Row(
          children: [
            Expanded(
              child: TextFormField(
                decoration: const InputDecoration(labelText: "Open path"),
                initialValue: _openPath,
                onChanged: (value) => _openPath = value,
              ),
            ),
            const SizedBox(width: 10),
            Expanded(
              child: TextFormField(
                decoration: const InputDecoration(labelText: "Default path"),
                initialValue: _defaultPath,
                onChanged: (value) => _defaultPath = value,
              ),
            ),
          ],
        ),
        Row(
          children: [
            Expanded(
              child: TextFormField(
                decoration: const InputDecoration(labelText: "Filter name"),
                initialValue: _filterName,
                onChanged: (value) => _filterName = value,
              ),
            ),
            const SizedBox(width: 10),
            Expanded(
              child: TextFormField(
                decoration: const InputDecoration(labelText: "Filter pattern"),
                initialValue: _filterPattern,
                onChanged: (value) => _filterPattern = value,
              ),
            ),
          ],
        ),
      ],
    );
  }

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      padding: const EdgeInsets.all(10),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        children: [
          _buildParameter(),
          const SizedBox(height: 20),
          ElevatedButton(
            child: const Text("pickFiles"),
            onPressed: _pickFiles,
          ),
          const SizedBox(height: 10),
          _buildResults(),
        ],
      ),
    );
  }
}
